# Text Clustering

This repository contains tools to easily embed and cluster texts as well as label clusters and produce visualizations of those labeled clusters. 

## Install 

Install the library to get started:

```bash
pip install --upgrade bocluster
```

## Usage

```python
```